Shared operations used by both the CLI and MCP server.
Structs
- Blast
Radius Result - Result of a blast radius query.
- Callers
Result - Result of a callers query.
- Dead
Code Result - Result of a dead code analysis.
- Module
Graph Result - Result of a module graph query.
- Node
Summary - A node summary (id, type, payload) used across multiple results.
- Query
Result - Result of a raw Datalog query.
- Search
Result - Result of a search query.
- Search
Result Item - A single search result row.
- Status
Result - Result of a status query.
- Trait
Implementors Result - Result of a trait implementors query.
Constants
- DEAD_
CODE_ CAVEAT - Caveat about dynamic dispatch included in dead code results.
Functions
- blast_
radius - Compute the blast radius from a given node.
- callers
- Find callers of a node up to a given depth.
- dead_
code - Find dead (unreachable) code with symbol names.
- module_
graph - Get the module containment graph.
- node_
info - Get full info for a node.
- query
- Run a raw Datalog query.
- search
- Run a text search.
- status
- Return graph status information including per-type breakdowns.
- trait_
implementors - Find implementors of a trait.